<?php

namespace App\idms\Controllers;

if (!defined('C8L6K7E')) {
    header("Location: /");
    die("Erro: Página não encontrada<br>");
}

/**
 * Controller editar a configuração de dominio
 * @author Cesar <cesar@celke.com.br>
 */
class EditConfigDominio
{

    /** @var array|string|null $data Recebe os dados que devem ser enviados para VIEW */
    private array|string|null $data = [];

    /** @var array $dataForm Recebe os dados do formulario */
    private array|null $dataForm;

    /**
     * Metodo editar a configuração de dominio
     * Receber os dados do formulario.
     * 
     * Se o usuario nao clicou no botao editar, instancia a MODELS para recuperar as informacoes no banco de dados, se encontrar instancia o metodo "viewConfigDominio". Se nao existir redireciona para o dashboard.
     * 
     * @return void
     */
    public function index(): void
    {
        $this->dataForm = filter_input_array(INPUT_POST, FILTER_DEFAULT);

        if (empty($this->dataForm['SendEditConfigDominio'])) {
            $viewConfigDominio = new \App\idms\Models\IdmsEditConfigDominio();
            $viewConfigDominio->viewConfigDominio();
            if ($viewConfigDominio->getResult()) {
                $this->data['form'] = $viewConfigDominio->getResultBd();
                $this->viewEditConfigDominio();
            } else {
                $urlRedirect = URLADM . "dashboard/index";
                header("Location: $urlRedirect");
            }
        } else {
            $this->editConfigDominio();
        }
    }

    /**
     * Instanciar a classe responsavel em carregar a View e enviar os dados para View.
     * 
     */
    private function viewEditConfigDominio(): void
    {
        $button = ['view_config_dominio' => ['menu_controller' => 'view-config-dominio', 'menu_metodo' => 'index']];
        $listBotton = new \App\adms\Models\helper\AdmsButton();
        $this->data['button'] = $listBotton->buttonPermission($button);

        $listSelect = new \App\idms\Models\IdmsEditConfigDominio();
        $this->data['select'] = $listSelect->listSelect();

        $listMenu = new \App\adms\Models\helper\AdmsMenu();
        $this->data['menu'] = $listMenu->itemMenu(); 
        
        $this->data['sidebarActive'] = "view-config-dominio"; 
        $loadView = new \Core\ConfigView("idms/Views/configDominio/editConfigDominio", $this->data);
        $loadView->loadView();
    }

    /**
     * Editar a configuração de dominio
     * Se o usuario clicou no botao, instancia a MODELS responsavel em receber os dados e editar no banco de dados.
     * Verifica se editou corretamente no banco de dados.
     * Se o usuario nao clicou no botao redireciona para pagina dashboard.
     *
     * @return void
     */
    private function editConfigDominio(): void
    {
        if (!empty($this->dataForm['SendEditConfigDominio'])) {
            unset($this->dataForm['SendEditConfigDominio']);
            $editConfigDominio = new \App\idms\Models\IdmsEditConfigDominio();
            $editConfigDominio->update($this->dataForm);
            if ($editConfigDominio->getResult()) {
                $urlRedirect = URLADM . "view-config-dominio/index/" . $this->dataForm['id'];
                header("Location: $urlRedirect");
            } else {
                $this->data['form'] = $this->dataForm;
                $this->viewEditConfigDominio();
            }
        } else {
            $_SESSION['msg'] = "<p class='alert-danger'>Erro: Página de configuração não encontrada!</p>";
            $urlRedirect = URLADM . "dashboard/index";
            header("Location: $urlRedirect");
        }
    }
}
