<?php

namespace App\idms\Models;

if (!defined('C8L6K7E')) {
    header("Location: /");
    die("Erro: Página não encontrada<br>");
}

/**
 * Apagar email no banco de dados
 *
 * @author Celke
 */
class IdmsDeleteEmailDelega
{

    /** @var bool $result Recebe true quando executar o processo com sucesso e false quando houver erro */
    private bool $result = false;

    /** @var int|string|null $id Recebe o id do registro */
    private int|string|null $id;

    /** @var array|null $resultBd Recebe os registros do banco de dados */
    private array|null $resultBd;

    /**
     * @return bool Retorna true quando executar o processo com sucesso e false quando houver erro
     */
    function getResult(): bool
    {
        return $this->result;
    }

    /**
     * Metodo recebe como parametro o ID do registro que será excluido
     * Chama as funções viewSit e checkColorUsed para fazer a confirmação do registro antes de excluir
     * @param integer $id
     * @return void
     */
    public function deleteEmailDelega(int $id): void
    {
        $this->id = (int) $id;

        if (($this->viewDelegaEmail()) and ($this->checkEmailDelegaUsed())) {
            $deleteEmailDelega = new \App\adms\Models\helper\AdmsDelete();
            $deleteEmailDelega->exeDelete("idms_email_delega", "WHERE id =:id", "id={$this->id}");

            if ($deleteEmailDelega->getResult()) {
                $_SESSION['msg'] = "<p class='alert-success'>Email apagado com sucesso!</p>";
                $this->result = true;
            } else {
                $_SESSION['msg'] = "<p class='alert-danger'>Erro: Email não apagado com sucesso!</p>";
                $this->result = false;
            }
        } else {
            $this->result = false;
        }
    }

    /**
     * Metodo verifica se a cor esta cadastrada na tabela e envia o resultado para a função deleteColor
     * @return boolean
     */
    private function viewEmailDelega(): bool
    {

        $viewEmailDelega = new \App\adms\Models\helper\AdmsRead();
        $viewEmailDelega->fullRead(
            "SELECT id
                            FROM idms_emails_delegados                           
                            WHERE id=:id
                            LIMIT :limit",
            "id={$this->id}&limit=1"
        );

        $this->resultBd = $viewEmailDelega->getResult();
        if ($this->resultBd) {
            return true;
        } else {
            $_SESSION['msg'] = "<p class='alert-danger'>Erro: Email não encontrado!</p>";
            return false;
        }
    }

    /**
     * Metodo verifica se tem situação cadastrados usando a cor a ser excluida, caso tenha a exclusão não é permitida
     * O resultado da pesquisa é enviada para a função deleteColor
     * @return boolean
     */
    private function checkEmailDelegaUsed(): bool
    {
        $viewEmailDelegaUsed = new \App\adms\Models\helper\AdmsRead();
        $viewEmailDelegaUsed->fullRead("SELECT id FROM adms_sits_users WHERE adms_color_id =:adms_color_id LIMIT :limit", "adms_color_id={$this->id}&limit=1");
        if ($viewEmailDelegaUsed->getResult()) {
            $_SESSION['msg'] = "<p class='alert-danger'>Erro: Email não pode ser apagado, já existe um email vinculado cadastrado!</p>";
            return false;
        } else {
            return true;
        }
    }
}
